// Copyright 2024 The Chromium Authors
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

// Generated by third_party/blink/renderer/build/scripts/generate_permission_element_grd.py

#include <stdint.h>

#include <optional>
#include <string_view>
#include <utility>

#include "base/containers/fixed_flat_map.h"
#include "base/containers/fixed_flat_set.h"
#include "base/strings/string_slice.h"
#include "third_party/blink/renderer/core/html/html_permission_element_strings_map.h"
#include "third_party/blink/public/strings/grit/permission_element_generated_strings.h"
#include "third_party/blink/public/strings/grit/permission_element_strings.h"

namespace blink {

namespace {

static constexpr char kLanguages[] =
    "afamarasazbebgbnbscacscydadeelenes-419eteufifilfr-caglguhihrhuhyidisitiwjakakkkmknkokyloltlvmlmnmrmsmynlnoorpaplpt-brroruskslsqsr-latnsvswtathtrukuruzvizhzh-hkzh-twzu";


using LangStringSlice = base::subtle::StringSlice<sizeof(kLanguages), kLanguages>;

// In C++20, pairs required exactly-matching types to be comparable, i.e.
// std::pair<T1, T2> cannot be compared against std::pair<U1, U2>, even if T1
// and T2 are comparable against U1 and U2. This was addressed in C++23 in
// https://cplusplus.github.io/LWG/issue3865. However, older versions of
// libstdc++ do not support this, so the lookup needs to be wrapped with a
// type that is heterogeneously comparable with the key pair type...
struct LookupHelper {
  std::string_view lang;
  uint16_t id;

  // The style guide requires operator== to be defined if operator<=> is
  // defined. However, operator== is never actually used, which causes a
  // compiler warning. Explicitly delete it instead... if it's ever needed,
  // the build will start failing.
  friend constexpr bool operator==(LookupHelper lhs,
                                   std::pair<LangStringSlice, uint16_t> rhs) = delete;
  friend constexpr auto operator<=>(LookupHelper lhs,
                                    std::pair<LangStringSlice, uint16_t> rhs) {
    return lhs.lang != rhs.first ?  lhs.lang <=> rhs.first : lhs.id <=> rhs.second;
  }
};

}  // namespace

std::optional<uint16_t> GetPermissionElementMessageId(
    std::string_view language_code,
    uint16_t base_message) {
  static constexpr auto kMessageIds =
      base::MakeFixedFlatMap<std::pair<LangStringSlice, uint16_t>, uint16_t>({
        {{{0, 2}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_af},
        {{{0, 2}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_af},
        {{{0, 2}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_af},
        {{{0, 2}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_af},
        {{{0, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_af},
        {{{0, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_af},
        {{{0, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_af},
        {{{0, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_af},
        {{{0, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_af},
        {{{0, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_af},
        {{{2, 2}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_am},
        {{{2, 2}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_am},
        {{{2, 2}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_am},
        {{{2, 2}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_am},
        {{{2, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_am},
        {{{2, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_am},
        {{{2, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_am},
        {{{2, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_am},
        {{{2, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_am},
        {{{2, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_am},
        {{{4, 2}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_ar},
        {{{4, 2}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_ar},
        {{{4, 2}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_ar},
        {{{4, 2}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_ar},
        {{{4, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_ar},
        {{{4, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_ar},
        {{{4, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_ar},
        {{{4, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ar},
        {{{4, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_ar},
        {{{4, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ar},
        {{{6, 2}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_as},
        {{{6, 2}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_as},
        {{{6, 2}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_as},
        {{{6, 2}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_as},
        {{{6, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_as},
        {{{6, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_as},
        {{{6, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_as},
        {{{6, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_as},
        {{{6, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_as},
        {{{6, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_as},
        {{{8, 2}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_az},
        {{{8, 2}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_az},
        {{{8, 2}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_az},
        {{{8, 2}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_az},
        {{{8, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_az},
        {{{8, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_az},
        {{{8, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_az},
        {{{8, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_az},
        {{{8, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_az},
        {{{8, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_az},
        {{{10, 2}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_be},
        {{{10, 2}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_be},
        {{{10, 2}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_be},
        {{{10, 2}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_be},
        {{{10, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_be},
        {{{10, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_be},
        {{{10, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_be},
        {{{10, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_be},
        {{{10, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_be},
        {{{10, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_be},
        {{{12, 2}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_bg},
        {{{12, 2}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_bg},
        {{{12, 2}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_bg},
        {{{12, 2}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_bg},
        {{{12, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_bg},
        {{{12, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_bg},
        {{{12, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_bg},
        {{{12, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_bg},
        {{{12, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_bg},
        {{{12, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_bg},
        {{{14, 2}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_bn},
        {{{14, 2}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_bn},
        {{{14, 2}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_bn},
        {{{14, 2}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_bn},
        {{{14, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_bn},
        {{{14, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_bn},
        {{{14, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_bn},
        {{{14, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_bn},
        {{{14, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_bn},
        {{{14, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_bn},
        {{{16, 2}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_bs},
        {{{16, 2}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_bs},
        {{{16, 2}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_bs},
        {{{16, 2}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_bs},
        {{{16, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_bs},
        {{{16, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_bs},
        {{{16, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_bs},
        {{{16, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_bs},
        {{{16, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_bs},
        {{{16, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_bs},
        {{{18, 2}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_ca},
        {{{18, 2}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_ca},
        {{{18, 2}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_ca},
        {{{18, 2}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_ca},
        {{{18, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_ca},
        {{{18, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_ca},
        {{{18, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_ca},
        {{{18, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ca},
        {{{18, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_ca},
        {{{18, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ca},
        {{{20, 2}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_cs},
        {{{20, 2}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_cs},
        {{{20, 2}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_cs},
        {{{20, 2}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_cs},
        {{{20, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_cs},
        {{{20, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_cs},
        {{{20, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_cs},
        {{{20, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_cs},
        {{{20, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_cs},
        {{{20, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_cs},
        {{{22, 2}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_cy},
        {{{22, 2}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_cy},
        {{{22, 2}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_cy},
        {{{22, 2}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_cy},
        {{{22, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_cy},
        {{{22, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_cy},
        {{{22, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_cy},
        {{{22, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_cy},
        {{{22, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_cy},
        {{{22, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_cy},
        {{{24, 2}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_da},
        {{{24, 2}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_da},
        {{{24, 2}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_da},
        {{{24, 2}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_da},
        {{{24, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_da},
        {{{24, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_da},
        {{{24, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_da},
        {{{24, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_da},
        {{{24, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_da},
        {{{24, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_da},
        {{{26, 2}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_de},
        {{{26, 2}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_de},
        {{{26, 2}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_de},
        {{{26, 2}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_de},
        {{{26, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_de},
        {{{26, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_de},
        {{{26, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_de},
        {{{26, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_de},
        {{{26, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_de},
        {{{26, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_de},
        {{{28, 2}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_el},
        {{{28, 2}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_el},
        {{{28, 2}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_el},
        {{{28, 2}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_el},
        {{{28, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_el},
        {{{28, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_el},
        {{{28, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_el},
        {{{28, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_el},
        {{{28, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_el},
        {{{28, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_el},
        {{{30, 2}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_en_GB},
        {{{30, 2}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_en_GB},
        {{{30, 2}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_en_GB},
        {{{30, 2}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_en_GB},
        {{{30, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_en_GB},
        {{{30, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_en_GB},
        {{{30, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_en_GB},
        {{{30, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_en_GB},
        {{{30, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_en_GB},
        {{{30, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_en_GB},
        {{{32, 2}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_es},
        {{{32, 2}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_es},
        {{{32, 2}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_es},
        {{{32, 2}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_es},
        {{{32, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_es},
        {{{32, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_es},
        {{{32, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_es},
        {{{32, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_es},
        {{{32, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_es},
        {{{32, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_es},
        {{{32, 6}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_es_419},
        {{{32, 6}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_es_419},
        {{{32, 6}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_es_419},
        {{{32, 6}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_es_419},
        {{{32, 6}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_es_419},
        {{{32, 6}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_es_419},
        {{{32, 6}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_es_419},
        {{{32, 6}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_es_419},
        {{{32, 6}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_es_419},
        {{{32, 6}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_es_419},
        {{{38, 2}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_et},
        {{{38, 2}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_et},
        {{{38, 2}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_et},
        {{{38, 2}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_et},
        {{{38, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_et},
        {{{38, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_et},
        {{{38, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_et},
        {{{38, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_et},
        {{{38, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_et},
        {{{38, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_et},
        {{{40, 2}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_eu},
        {{{40, 2}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_eu},
        {{{40, 2}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_eu},
        {{{40, 2}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_eu},
        {{{40, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_eu},
        {{{40, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_eu},
        {{{40, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_eu},
        {{{40, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_eu},
        {{{40, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_eu},
        {{{40, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_eu},
        {{{1, 2}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_fa},
        {{{1, 2}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_fa},
        {{{1, 2}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_fa},
        {{{1, 2}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_fa},
        {{{1, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_fa},
        {{{1, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_fa},
        {{{1, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_fa},
        {{{1, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_fa},
        {{{1, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_fa},
        {{{1, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_fa},
        {{{42, 2}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_fi},
        {{{42, 2}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_fi},
        {{{42, 2}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_fi},
        {{{42, 2}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_fi},
        {{{42, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_fi},
        {{{42, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_fi},
        {{{42, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_fi},
        {{{42, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_fi},
        {{{42, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_fi},
        {{{42, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_fi},
        {{{44, 3}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_fil},
        {{{44, 3}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_fil},
        {{{44, 3}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_fil},
        {{{44, 3}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_fil},
        {{{44, 3}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_fil},
        {{{44, 3}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_fil},
        {{{44, 3}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_fil},
        {{{44, 3}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_fil},
        {{{44, 3}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_fil},
        {{{44, 3}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_fil},
        {{{47, 2}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_fr},
        {{{47, 2}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_fr},
        {{{47, 2}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_fr},
        {{{47, 2}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_fr},
        {{{47, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_fr},
        {{{47, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_fr},
        {{{47, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_fr},
        {{{47, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_fr},
        {{{47, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_fr},
        {{{47, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_fr},
        {{{47, 5}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_fr_CA},
        {{{47, 5}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_fr_CA},
        {{{47, 5}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_fr_CA},
        {{{47, 5}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_fr_CA},
        {{{47, 5}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_fr_CA},
        {{{47, 5}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_fr_CA},
        {{{47, 5}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_fr_CA},
        {{{47, 5}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_fr_CA},
        {{{47, 5}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_fr_CA},
        {{{47, 5}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_fr_CA},
        {{{52, 2}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_gl},
        {{{52, 2}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_gl},
        {{{52, 2}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_gl},
        {{{52, 2}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_gl},
        {{{52, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_gl},
        {{{52, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_gl},
        {{{52, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_gl},
        {{{52, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_gl},
        {{{52, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_gl},
        {{{52, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_gl},
        {{{54, 2}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_gu},
        {{{54, 2}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_gu},
        {{{54, 2}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_gu},
        {{{54, 2}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_gu},
        {{{54, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_gu},
        {{{54, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_gu},
        {{{54, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_gu},
        {{{54, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_gu},
        {{{54, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_gu},
        {{{54, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_gu},
        {{{56, 2}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_hi},
        {{{56, 2}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_hi},
        {{{56, 2}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_hi},
        {{{56, 2}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_hi},
        {{{56, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_hi},
        {{{56, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_hi},
        {{{56, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_hi},
        {{{56, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_hi},
        {{{56, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_hi},
        {{{56, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_hi},
        {{{58, 2}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_hr},
        {{{58, 2}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_hr},
        {{{58, 2}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_hr},
        {{{58, 2}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_hr},
        {{{58, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_hr},
        {{{58, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_hr},
        {{{58, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_hr},
        {{{58, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_hr},
        {{{58, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_hr},
        {{{58, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_hr},
        {{{60, 2}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_hu},
        {{{60, 2}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_hu},
        {{{60, 2}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_hu},
        {{{60, 2}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_hu},
        {{{60, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_hu},
        {{{60, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_hu},
        {{{60, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_hu},
        {{{60, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_hu},
        {{{60, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_hu},
        {{{60, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_hu},
        {{{62, 2}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_hy},
        {{{62, 2}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_hy},
        {{{62, 2}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_hy},
        {{{62, 2}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_hy},
        {{{62, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_hy},
        {{{62, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_hy},
        {{{62, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_hy},
        {{{62, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_hy},
        {{{62, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_hy},
        {{{62, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_hy},
        {{{64, 2}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_id},
        {{{64, 2}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_id},
        {{{64, 2}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_id},
        {{{64, 2}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_id},
        {{{64, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_id},
        {{{64, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_id},
        {{{64, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_id},
        {{{64, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_id},
        {{{64, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_id},
        {{{64, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_id},
        {{{66, 2}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_is},
        {{{66, 2}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_is},
        {{{66, 2}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_is},
        {{{66, 2}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_is},
        {{{66, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_is},
        {{{66, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_is},
        {{{66, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_is},
        {{{66, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_is},
        {{{66, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_is},
        {{{66, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_is},
        {{{68, 2}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_it},
        {{{68, 2}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_it},
        {{{68, 2}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_it},
        {{{68, 2}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_it},
        {{{68, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_it},
        {{{68, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_it},
        {{{68, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_it},
        {{{68, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_it},
        {{{68, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_it},
        {{{68, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_it},
        {{{70, 2}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_iw},
        {{{70, 2}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_iw},
        {{{70, 2}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_iw},
        {{{70, 2}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_iw},
        {{{70, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_iw},
        {{{70, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_iw},
        {{{70, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_iw},
        {{{70, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_iw},
        {{{70, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_iw},
        {{{70, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_iw},
        {{{72, 2}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_ja},
        {{{72, 2}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_ja},
        {{{72, 2}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_ja},
        {{{72, 2}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_ja},
        {{{72, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_ja},
        {{{72, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_ja},
        {{{72, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_ja},
        {{{72, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ja},
        {{{72, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_ja},
        {{{72, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ja},
        {{{74, 2}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_ka},
        {{{74, 2}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_ka},
        {{{74, 2}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_ka},
        {{{74, 2}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_ka},
        {{{74, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_ka},
        {{{74, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_ka},
        {{{74, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_ka},
        {{{74, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ka},
        {{{74, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_ka},
        {{{74, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ka},
        {{{76, 2}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_kk},
        {{{76, 2}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_kk},
        {{{76, 2}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_kk},
        {{{76, 2}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_kk},
        {{{76, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_kk},
        {{{76, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_kk},
        {{{76, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_kk},
        {{{76, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_kk},
        {{{76, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_kk},
        {{{76, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_kk},
        {{{78, 2}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_km},
        {{{78, 2}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_km},
        {{{78, 2}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_km},
        {{{78, 2}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_km},
        {{{78, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_km},
        {{{78, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_km},
        {{{78, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_km},
        {{{78, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_km},
        {{{78, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_km},
        {{{78, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_km},
        {{{80, 2}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_kn},
        {{{80, 2}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_kn},
        {{{80, 2}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_kn},
        {{{80, 2}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_kn},
        {{{80, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_kn},
        {{{80, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_kn},
        {{{80, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_kn},
        {{{80, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_kn},
        {{{80, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_kn},
        {{{80, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_kn},
        {{{82, 2}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_ko},
        {{{82, 2}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_ko},
        {{{82, 2}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_ko},
        {{{82, 2}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_ko},
        {{{82, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_ko},
        {{{82, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_ko},
        {{{82, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_ko},
        {{{82, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ko},
        {{{82, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_ko},
        {{{82, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ko},
        {{{84, 2}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_ky},
        {{{84, 2}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_ky},
        {{{84, 2}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_ky},
        {{{84, 2}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_ky},
        {{{84, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_ky},
        {{{84, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_ky},
        {{{84, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_ky},
        {{{84, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ky},
        {{{84, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_ky},
        {{{84, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ky},
        {{{86, 2}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_lo},
        {{{86, 2}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_lo},
        {{{86, 2}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_lo},
        {{{86, 2}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_lo},
        {{{86, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_lo},
        {{{86, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_lo},
        {{{86, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_lo},
        {{{86, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_lo},
        {{{86, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_lo},
        {{{86, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_lo},
        {{{88, 2}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_lt},
        {{{88, 2}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_lt},
        {{{88, 2}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_lt},
        {{{88, 2}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_lt},
        {{{88, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_lt},
        {{{88, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_lt},
        {{{88, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_lt},
        {{{88, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_lt},
        {{{88, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_lt},
        {{{88, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_lt},
        {{{90, 2}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_lv},
        {{{90, 2}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_lv},
        {{{90, 2}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_lv},
        {{{90, 2}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_lv},
        {{{90, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_lv},
        {{{90, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_lv},
        {{{90, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_lv},
        {{{90, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_lv},
        {{{90, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_lv},
        {{{90, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_lv},
        {{{79, 2}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_mk},
        {{{79, 2}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_mk},
        {{{79, 2}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_mk},
        {{{79, 2}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_mk},
        {{{79, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_mk},
        {{{79, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_mk},
        {{{79, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_mk},
        {{{79, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_mk},
        {{{79, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_mk},
        {{{79, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_mk},
        {{{92, 2}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_ml},
        {{{92, 2}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_ml},
        {{{92, 2}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_ml},
        {{{92, 2}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_ml},
        {{{92, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_ml},
        {{{92, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_ml},
        {{{92, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_ml},
        {{{92, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ml},
        {{{92, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_ml},
        {{{92, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ml},
        {{{94, 2}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_mn},
        {{{94, 2}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_mn},
        {{{94, 2}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_mn},
        {{{94, 2}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_mn},
        {{{94, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_mn},
        {{{94, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_mn},
        {{{94, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_mn},
        {{{94, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_mn},
        {{{94, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_mn},
        {{{94, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_mn},
        {{{96, 2}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_mr},
        {{{96, 2}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_mr},
        {{{96, 2}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_mr},
        {{{96, 2}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_mr},
        {{{96, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_mr},
        {{{96, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_mr},
        {{{96, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_mr},
        {{{96, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_mr},
        {{{96, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_mr},
        {{{96, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_mr},
        {{{98, 2}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_ms},
        {{{98, 2}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_ms},
        {{{98, 2}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_ms},
        {{{98, 2}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_ms},
        {{{98, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_ms},
        {{{98, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_ms},
        {{{98, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_ms},
        {{{98, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ms},
        {{{98, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_ms},
        {{{98, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ms},
        {{{100, 2}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_my},
        {{{100, 2}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_my},
        {{{100, 2}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_my},
        {{{100, 2}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_my},
        {{{100, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_my},
        {{{100, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_my},
        {{{100, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_my},
        {{{100, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_my},
        {{{100, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_my},
        {{{100, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_my},
        {{{31, 2}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_ne},
        {{{31, 2}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_ne},
        {{{31, 2}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_ne},
        {{{31, 2}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_ne},
        {{{31, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_ne},
        {{{31, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_ne},
        {{{31, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_ne},
        {{{31, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ne},
        {{{31, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_ne},
        {{{31, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ne},
        {{{102, 2}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_nl},
        {{{102, 2}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_nl},
        {{{102, 2}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_nl},
        {{{102, 2}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_nl},
        {{{102, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_nl},
        {{{102, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_nl},
        {{{102, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_nl},
        {{{102, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_nl},
        {{{102, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_nl},
        {{{102, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_nl},
        {{{104, 2}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_no},
        {{{104, 2}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_no},
        {{{104, 2}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_no},
        {{{104, 2}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_no},
        {{{104, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_no},
        {{{104, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_no},
        {{{104, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_no},
        {{{104, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_no},
        {{{104, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_no},
        {{{104, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_no},
        {{{106, 2}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_or},
        {{{106, 2}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_or},
        {{{106, 2}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_or},
        {{{106, 2}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_or},
        {{{106, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_or},
        {{{106, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_or},
        {{{106, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_or},
        {{{106, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_or},
        {{{106, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_or},
        {{{106, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_or},
        {{{108, 2}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_pa},
        {{{108, 2}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_pa},
        {{{108, 2}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_pa},
        {{{108, 2}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_pa},
        {{{108, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_pa},
        {{{108, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_pa},
        {{{108, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_pa},
        {{{108, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_pa},
        {{{108, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_pa},
        {{{108, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_pa},
        {{{110, 2}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_pl},
        {{{110, 2}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_pl},
        {{{110, 2}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_pl},
        {{{110, 2}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_pl},
        {{{110, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_pl},
        {{{110, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_pl},
        {{{110, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_pl},
        {{{110, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_pl},
        {{{110, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_pl},
        {{{110, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_pl},
        {{{112, 2}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_pt_PT},
        {{{112, 2}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_pt_PT},
        {{{112, 2}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_pt_PT},
        {{{112, 2}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_pt_PT},
        {{{112, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_pt_PT},
        {{{112, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_pt_PT},
        {{{112, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_pt_PT},
        {{{112, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_pt_PT},
        {{{112, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_pt_PT},
        {{{112, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_pt_PT},
        {{{112, 5}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_pt_BR},
        {{{112, 5}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_pt_BR},
        {{{112, 5}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_pt_BR},
        {{{112, 5}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_pt_BR},
        {{{112, 5}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_pt_BR},
        {{{112, 5}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_pt_BR},
        {{{112, 5}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_pt_BR},
        {{{112, 5}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_pt_BR},
        {{{112, 5}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_pt_BR},
        {{{112, 5}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_pt_BR},
        {{{117, 2}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_ro},
        {{{117, 2}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_ro},
        {{{117, 2}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_ro},
        {{{117, 2}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_ro},
        {{{117, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_ro},
        {{{117, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_ro},
        {{{117, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_ro},
        {{{117, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ro},
        {{{117, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_ro},
        {{{117, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ro},
        {{{119, 2}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_ru},
        {{{119, 2}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_ru},
        {{{119, 2}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_ru},
        {{{119, 2}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_ru},
        {{{119, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_ru},
        {{{119, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_ru},
        {{{119, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_ru},
        {{{119, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ru},
        {{{119, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_ru},
        {{{119, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ru},
        {{{67, 2}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_si},
        {{{67, 2}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_si},
        {{{67, 2}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_si},
        {{{67, 2}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_si},
        {{{67, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_si},
        {{{67, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_si},
        {{{67, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_si},
        {{{67, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_si},
        {{{67, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_si},
        {{{67, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_si},
        {{{121, 2}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_sk},
        {{{121, 2}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_sk},
        {{{121, 2}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_sk},
        {{{121, 2}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_sk},
        {{{121, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_sk},
        {{{121, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_sk},
        {{{121, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_sk},
        {{{121, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_sk},
        {{{121, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_sk},
        {{{121, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_sk},
        {{{123, 2}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_sl},
        {{{123, 2}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_sl},
        {{{123, 2}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_sl},
        {{{123, 2}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_sl},
        {{{123, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_sl},
        {{{123, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_sl},
        {{{123, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_sl},
        {{{123, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_sl},
        {{{123, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_sl},
        {{{123, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_sl},
        {{{125, 2}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_sq},
        {{{125, 2}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_sq},
        {{{125, 2}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_sq},
        {{{125, 2}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_sq},
        {{{125, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_sq},
        {{{125, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_sq},
        {{{125, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_sq},
        {{{125, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_sq},
        {{{125, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_sq},
        {{{125, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_sq},
        {{{127, 2}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_sr},
        {{{127, 2}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_sr},
        {{{127, 2}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_sr},
        {{{127, 2}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_sr},
        {{{127, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_sr},
        {{{127, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_sr},
        {{{127, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_sr},
        {{{127, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_sr},
        {{{127, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_sr},
        {{{127, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_sr},
        {{{127, 7}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_sr_Latn},
        {{{127, 7}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_sr_Latn},
        {{{127, 7}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_sr_Latn},
        {{{127, 7}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_sr_Latn},
        {{{127, 7}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_sr_Latn},
        {{{127, 7}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_sr_Latn},
        {{{127, 7}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_sr_Latn},
        {{{127, 7}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_sr_Latn},
        {{{127, 7}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_sr_Latn},
        {{{127, 7}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_sr_Latn},
        {{{134, 2}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_sv},
        {{{134, 2}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_sv},
        {{{134, 2}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_sv},
        {{{134, 2}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_sv},
        {{{134, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_sv},
        {{{134, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_sv},
        {{{134, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_sv},
        {{{134, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_sv},
        {{{134, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_sv},
        {{{134, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_sv},
        {{{136, 2}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_sw},
        {{{136, 2}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_sw},
        {{{136, 2}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_sw},
        {{{136, 2}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_sw},
        {{{136, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_sw},
        {{{136, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_sw},
        {{{136, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_sw},
        {{{136, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_sw},
        {{{136, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_sw},
        {{{136, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_sw},
        {{{138, 2}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_ta},
        {{{138, 2}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_ta},
        {{{138, 2}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_ta},
        {{{138, 2}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_ta},
        {{{138, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_ta},
        {{{138, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_ta},
        {{{138, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_ta},
        {{{138, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ta},
        {{{138, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_ta},
        {{{138, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ta},
        {{{39, 2}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_te},
        {{{39, 2}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_te},
        {{{39, 2}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_te},
        {{{39, 2}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_te},
        {{{39, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_te},
        {{{39, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_te},
        {{{39, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_te},
        {{{39, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_te},
        {{{39, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_te},
        {{{39, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_te},
        {{{140, 2}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_th},
        {{{140, 2}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_th},
        {{{140, 2}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_th},
        {{{140, 2}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_th},
        {{{140, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_th},
        {{{140, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_th},
        {{{140, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_th},
        {{{140, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_th},
        {{{140, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_th},
        {{{140, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_th},
        {{{142, 2}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_tr},
        {{{142, 2}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_tr},
        {{{142, 2}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_tr},
        {{{142, 2}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_tr},
        {{{142, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_tr},
        {{{142, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_tr},
        {{{142, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_tr},
        {{{142, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_tr},
        {{{142, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_tr},
        {{{142, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_tr},
        {{{144, 2}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_uk},
        {{{144, 2}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_uk},
        {{{144, 2}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_uk},
        {{{144, 2}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_uk},
        {{{144, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_uk},
        {{{144, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_uk},
        {{{144, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_uk},
        {{{144, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_uk},
        {{{144, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_uk},
        {{{144, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_uk},
        {{{146, 2}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_ur},
        {{{146, 2}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_ur},
        {{{146, 2}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_ur},
        {{{146, 2}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_ur},
        {{{146, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_ur},
        {{{146, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_ur},
        {{{146, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_ur},
        {{{146, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ur},
        {{{146, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_ur},
        {{{146, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ur},
        {{{148, 2}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_uz},
        {{{148, 2}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_uz},
        {{{148, 2}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_uz},
        {{{148, 2}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_uz},
        {{{148, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_uz},
        {{{148, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_uz},
        {{{148, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_uz},
        {{{148, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_uz},
        {{{148, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_uz},
        {{{148, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_uz},
        {{{150, 2}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_vi},
        {{{150, 2}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_vi},
        {{{150, 2}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_vi},
        {{{150, 2}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_vi},
        {{{150, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_vi},
        {{{150, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_vi},
        {{{150, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_vi},
        {{{150, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_vi},
        {{{150, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_vi},
        {{{150, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_vi},
        {{{152, 2}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_zh_CN},
        {{{152, 2}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_zh_CN},
        {{{152, 2}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_zh_CN},
        {{{152, 2}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_zh_CN},
        {{{152, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_zh_CN},
        {{{152, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_zh_CN},
        {{{152, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_zh_CN},
        {{{152, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_zh_CN},
        {{{152, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_zh_CN},
        {{{152, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_zh_CN},
        {{{154, 5}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_zh_HK},
        {{{154, 5}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_zh_HK},
        {{{154, 5}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_zh_HK},
        {{{154, 5}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_zh_HK},
        {{{154, 5}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_zh_HK},
        {{{154, 5}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_zh_HK},
        {{{154, 5}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_zh_HK},
        {{{154, 5}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_zh_HK},
        {{{154, 5}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_zh_HK},
        {{{154, 5}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_zh_HK},
        {{{159, 5}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_zh_TW},
        {{{159, 5}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_zh_TW},
        {{{159, 5}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_zh_TW},
        {{{159, 5}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_zh_TW},
        {{{159, 5}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_zh_TW},
        {{{159, 5}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_zh_TW},
        {{{159, 5}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_zh_TW},
        {{{159, 5}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_zh_TW},
        {{{159, 5}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_zh_TW},
        {{{159, 5}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_zh_TW},
        {{{164, 2}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_zu},
        {{{164, 2}, IDS_PERMISSION_REQUEST_CAMERA}, IDS_PERMISSION_REQUEST_CAMERA_zu},
        {{{164, 2}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_zu},
        {{{164, 2}, IDS_PERMISSION_REQUEST_MICROPHONE}, IDS_PERMISSION_REQUEST_MICROPHONE_zu},
        {{{164, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_zu},
        {{{164, 2}, IDS_PERMISSION_REQUEST_GEOLOCATION}, IDS_PERMISSION_REQUEST_GEOLOCATION_zu},
        {{{164, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_zu},
        {{{164, 2}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE}, IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_zu},
        {{{164, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_zu},
        {{{164, 2}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION}, IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_zu},

      });

  auto message = kMessageIds.find(
      LookupHelper{language_code, static_cast<uint16_t>(base_message)});
  return message == kMessageIds.end()
      ? std::nullopt
      : std::optional(message->second);
}

}  // namespace blink
